\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{awbook}
\LoadClass{book}

%\usepackage{times-bt}
\usepackage{times}
\usepackage{schulzrinne}
\usepackage{fancyheadings}
\usepackage{multicol}
\usepackage{float}
\usepackage{supertabular}

% table of contents look
\setcounter{topnumber}{1}
%%%\setcounter{tocdepth}{1}
\setcounter{tocdepth}{3}	% for now, for a better look at stuff

% basic dimensions
\setlength{\textheight}{7.625in}
\setlength{\textwidth}{5.375in}


% Set styles for floats
\def\Tfloatc@plain#1#2{\medskip\setbox\@tempboxa\hbox{{\@fs@cfont #1:} #2}%
  \ifdim\wd\@tempboxa>\hsize {\@fs@cfont #1:} #2\par
    \else\hbox to\hsize{\hfil\box\@tempboxa\hfil}\fi}

\def\floatc@plainsmall#1#2{\setbox\@tempboxa\hbox{{\@fs@cfont #1:} {\small #2}}%
  \ifdim\wd\@tempboxa>\hsize {\@fs@cfont #1:} {\small #2}\par
  \else\hbox to\hsize{\hfil\box\@tempboxa\hfil}\fi}

% Style for figures and tables, respectively
\def\fs@tbruledf{\def\@fs@cfont{\small\bf}\def\@fs@capt{\medskip\floatc@plainsmall}
  \def\@fs@pre{}%
% \def\@fs@pre{\hrule height.1pt depth0pt \kern12pt}%
  \def\@fs@post{\kern10pt\centerline{\rule{28pc}{.1pt}}}%
  \def\@fs@mid{}%
  \let\@fs@iftopcapt\iffalse}

\def\fs@tbruledt{\def\@fs@cfont{\small\bf}\def\@fs@capt{\medskip\floatc@plainsmall}
  \def\@fs@pre{}%
% \def\@fs@pre{\hrule height.1pt depth0pt \kern2pt}%
  \def\@fs@post{\kern2pt\centerline{\rule{28pc}{.1pt}}}%
  \def\@fs@mid{}%
  \let\@fs@iftopcapt\iftrue}

\floatstyle{tbruledf}
\restylefloat{figure}
\floatstyle{tbruledt}
\restylefloat{table}

\floatstyle{plain}
\newfloat{sides}{tp}{los}[chapter]
\renewcommand{\topfraction}{.75}
\renewcommand{\bottomfraction}{.75}
\renewcommand{\textfraction}{.25}
\renewcommand{\floatpagefraction}{.70}

% Headings
%\newfont{\Hixvi}{rphvb at 26 pt}
%\newfont{\Hbx}{rphvb at 10 pt}
%\newfont{\Hbxiv}{rphvb at 14 pt}

\DeclareFixedFont{\Hixvi}{\encodingdefault}{phv}{\seriesdefault}{\shapedefault}{26pt}
\DeclareFixedFont{\Hbx}{\encodingdefault}{phv}{\seriesdefault}{\shapedefault}{10pt}
\DeclareFixedFont{\Hbxiv}{\encodingdefault}{phv}{\seriesdefault}{\shapedefault}{14pt}

\def\Secexdent{.5in}

\pagestyle{fancyplain}
\addtolength{\headwidth}{\Secexdent}
\addtolength{\headheight}{2.5pt}

\addtolength{\textheight}{-\headheight}
\addtolength{\textheight}{-\headsep}

\lhead[\fancyplain{}{\bf\thepage}]{\fancyplain{}{\rightmark}}
\rhead[\fancyplain{}{\leftmark}]{\fancyplain{}{\bf\thepage}}

\cfoot{\fancyplain{}{}}
\lfoot{}
\rfoot[\fancyplain{}{}]{\fancyplain{\bf\thepage}{}}
%\cfoot{\fancyplain{}{\today\ \ \ \ }}
%\lfoot{Copyright \copyright 1994, 1995, 1996 by AT\&T}
%\rfoot[\fancyplain{}{DO NOT DUPLICATE/REDISTRIBUTE}]{\fancyplain{\bf\thepage}{DO NOT DUPLICATE/REDISTRIBUTE}}

\renewcommand{\sectionmark}[1]{\markright{{#1}}}
\renewcommand{\chaptermark}[1]{\markboth{{#1}}{}}
%\setlength{\oddheadoffset}{-\Secexdent}
%\setlength{\oddfootoffset}{-\Secexdent}
\fancyheadoffset[OL]{\Secexdent}
\fancyfootoffset[OL]{\Secexdent}
\fancyheadoffset[EL]{\Secexdent}
\fancyfootoffset[EL]{\Secexdent}

\addtolength{\abovedisplayskip}{3pt}
\addtolength{\belowdisplayskip}{3pt}
\addtolength{\abovedisplayshortskip}{3pt}
\addtolength{\belowdisplayshortskip}{3pt}

\setlength\marginparwidth{0.6in}

% part/chapter/section headings; TOC entries for them
\def\@part[#1]#2{\thispagestyle{empty}%
	\ifnum \c@secnumdepth >-2\relax
        \refstepcounter{part}%

        \addcontentsline{toc}{part}{\thepart
        \hspace{1em}#1}\else

        \addcontentsline{toc}{part}{#1}\fi
   \markboth{}{}%
   {
    \interlinepenalty \@M
    \ifnum \c@secnumdepth >-2\relax
      \huge\Hixvi \partname~\thepart \hfill
    \par
    \vskip 20\p@\fi
    \huge\Hixvi
    #2\hfill\par\rule{.6\textwidth}{1pt}}\@endpart}

\def\section{\@startsection {section}{1}{-\Secexdent}{-3.5ex plus-1ex minus
    -.2ex}{2.3ex plus.2ex}{\reset@font\Large\sf}}
\def\subsection{\@startsection{subsection}{2}{\z@}{-2.25ex plus-1ex
    minus-.2ex}{1.5ex plus.2ex}{\reset@font\large\sf}}
\def\subsubsection{\@startsection{subsubsection}{3}{\z@}{-2.25ex plus
    -1ex minus-.2ex}{1.5ex plus.2ex}{\reset@font\normalsize\sf}}

% \@makechapterhead {TEXT} : Makes the heading for the \chapter
% command.
%
 
\def\@makechapterhead#1{%           % Heading for \chapter command
  \vspace*{50\p@}%                  % Space at top of text page.
  {\parindent \z@ \raggedright 
    \ifnum \c@secnumdepth >\m@ne    % IF secnumdepth > -1 THEN
      \huge\Hixvi \@chapapp{}  \thechapter % Print 'Chapter' and number.
      \par 
      \vskip 20\p@ \fi              % Space between number and title.
    \Huge \Hixvi                       % Title.
    #1\par 
    \nobreak                        % TeX penalty to prevent page break.
    \vskip 40\p@                    % Space between title and text.
  }}

\def\chaptername{}
 
% \@makeschapterhead {TEXT} : Makes the heading for the \chapter*
% command.
%
 
\def\@makeschapterhead#1{%          % Heading for \chapter* command
  \vspace*{50\p@}%                  % Space at top of page.
  {\parindent \z@ \raggedright 
    \Huge \Hixvi                      % Title.
    #1\par 
    \nobreak                        % TeX penalty to prevent page break.
    \vskip 40\p@                    % Space between title and text.
  }}

\def\@sect#1#2#3#4#5#6[#7]#8{\ifnum #2>\c@secnumdepth
     \let\@svsec\@empty\else
     \refstepcounter{#1}\edef\@svsecSMB{\csname the#1\endcsname\hskip 1em}%
	     \@tempskipa #3\relax%
	     \ifdim \@tempskipa<\z@%
		\def\@svsec{\makebox[-#3][l]{\@svsecSMB}}%
		\else \def\@svsec{\@svsecSMB}%
	     \fi%
	\fi
     \@tempskipa #5\relax
      \ifdim \@tempskipa>\z@
        \begingroup #6\relax
          \@hangfrom{\hskip #3\relax\@svsec}{\interlinepenalty \@M #8\par}%
        \endgroup
       \csname #1mark\endcsname{#7}\addcontentsline
         {toc}{#1}{\ifnum #2>\c@secnumdepth \else
                      \protect\numberline{\csname the#1\endcsname}\fi
                    #7}\else
        \def\@svsechd{#6\hskip #3\relax  %% \relax added 2 May 90
                   \@svsec #8\csname #1mark\endcsname
                      {#7}\addcontentsline
                           {toc}{#1}{\ifnum #2>\c@secnumdepth \else
                             \protect\numberline{\csname the#1\endcsname}\fi
                       #7}}\fi
     \@xsect{#5}}

% \@dottedtocline{LEVEL}{INDENT}{NUMWIDTH}{TITLE}{PAGE} :
%   Macro to produce a table of contents line with the following
%   parameters:
%     LEVEL    : If LEVEL > \c@tocdepth, then no line produced.
%     INDENT   : Total indentation from the left margin.
%     NUMWIDTH : Width of box for number if the TITLE has a
%                \numberline command.
%                As of 25 Jan 88, this is also the amount of extra indentation
%                added to second and later lines of a multiple line entry.
%     TITLE    : Contents of entry.
%     PAGE     : Page number.
%
%  Uses the following parameters, which must be set by the document style.
%  They should be defined with \def's.
%    \@pnumwidth : Width of box in which page number is set.
%    \@tocrmarg  : Right margin indentation for all but last line of
%                  multiple-line entries.
%    \@dotsep    : Separation between dots, in mu units.  Should be \def'd to
%                  a number like 2 or 1.7
%

\def\@pnumwidth{1.75em}
\def\@tocrmarg {2.75em}
\def\@dotsep{4.5}

% \def\@showstatus{\hbox to 0pt{\@status}\hskip 1em \@status\stretch{-1}\def\@status{\null}}
\def\@showstatus{\null}

%% smb -- change described below deleted
%% RmS 91/09/29: added \reset@font for page number
\def\@dottedtocline#1#2#3#4#5{\ifnum #1>\c@tocdepth \else
  \vskip \z@ plus.2\p@
  {\leftskip #2\relax \rightskip \@tocrmarg \parfillskip -\rightskip
    \parindent #2\relax\@afterindenttrue
   \interlinepenalty\@M
   \leavevmode
   \@tempdima #3\relax \advance\leftskip \@tempdima \hbox{}\hskip -\leftskip
    #4\nobreak\leaders\hbox{$\m@th \mkern \@dotsep mu.\mkern \@dotsep
       mu$}\hfill \nobreak
           \hbox to\@pnumwidth{\hfil #5}\@showstatus\par}\fi}
%           \hbox to\@pnumwidth{\hfil\reset@font\rm #5}\par}\fi}


% TOC stuff

\def\l@part#1#2{\addpenalty{-\@highpenalty}%
   \addvspace{2.25em plus\p@}% space above part line
   \begingroup
   \@tempdima 3em
     \parindent \z@ \rightskip \@pnumwidth
     \parfillskip -\@pnumwidth
     {\large \Hbxiv
     \leavevmode
      \advance\leftskip\@tempdima
      \hskip -\leftskip
     #1\nobreak\hfil \nobreak\hbox to\@pnumwidth{\hss #2}}\par
     \nobreak
    \global\@nobreaktrue
    \everypar{\global\@nobreakfalse\everypar{}}%% suggested by

   \endgroup}

\def\l@chapter#1#2{\addpenalty{-\@highpenalty}%
   \vskip 1.0em plus\p@
   \@tempdima 1.5em
   \begingroup
     \parindent \z@ \rightskip \@pnumwidth
     \parfillskip -\@pnumwidth
     \Hbx
     \leavevmode
      \advance\leftskip\@tempdima
      \hskip -\leftskip
     #1\nobreak\hfil \nobreak\hbox to\@pnumwidth{\hss #2}\par
     \penalty\@highpenalty
   \endgroup}

\def\l@section{\sf \@dottedtocline{1}{1.5em}{2.8em}}
% a little larger - ches 
% \def\l@subsection{\sf \@dottedtocline{2}{4.3em}{3.2em}}
\def\l@subsection{\sf \@dottedtocline{2}{4.6em}{3.4em}}
\def\l@subsubsection{\sf \@dottedtocline{3}{7.6em}{4.1em}}
\def\l@subparagraph{\sf \@dottedtocline{5}{15.7em}{6em}}

\def\listoffigures{\@restonecolfalse
  \if@twocolumn\@restonecoltrue\onecolumn\fi
  \chapter*{\listfigurename\@mkboth{\uppercase{\listfigurename}}%
    {\uppercase{\listfigurename}}}\addcontentsline{toc}{chapter}{\listfigurename}%
    \@starttoc{lof}\if@restonecol
   \twocolumn\fi%
}

\def\l@figure{\sf \@dottedtocline{1}{1.5em}{2.3em}}

\def\listoftables{\@restonecolfalse
  \if@twocolumn\@restonecoltrue\onecolumn\fi
  \chapter*{\listtablename\@mkboth{\uppercase{\listtablename}}%
     {\uppercase{\listtablename}}}\addcontentsline{toc}{chapter}{\listtablename}%
     \@starttoc{lot}\if@restonecol
    \twocolumn\fi%
}

\let\l@table\l@figure

% Bibliography
\def\thebibliography#1{\chapter*{\bibname\@mkboth
  {{\bibname}}{{\bibname}}}%
  \@ifundefined{bibcomment}{\relax}{\bibcomment}\list
  {\@biblabel{\arabic{enumiv}}}{\settowidth\labelwidth{\@biblabel{#1}}%
    \leftmargin\labelwidth
    \advance\leftmargin\labelsep
    \usecounter{enumiv}%
    \let\p@enumiv\@empty
    \def\theenumiv{\arabic{enumiv}}}%
    \def\newblock{\hskip .11em plus.33em minus.07em}%
    \sloppy\clubpenalty4000\widowpenalty4000
    \sfcode`\.=\@m}

\def\endthebibliography{%
  \def\@noitemerr{\@warning{Empty `thebibliography' environment}}%
  \endlist}

%\renewenvironment{theindex}
%               {\if@twocolumn
%                  \@restonecolfalse
%                \else
%                  \@restonecoltrue
%                \fi
%                \columnseprule \z@
%                \columnsep 35\p@
%                \twocolumn[\@makeschapterhead{\indexname}]%
%                \@mkboth{\indexname}%
%                        {\indexname}%
%                \thispagestyle{plain}\parindent\z@
%                \parskip\z@ \@plus .3\p@\relax
%                \let\item\@idxitem}
%               {\if@restonecol\onecolumn\else\clearpage\fi}
\renewcommand\@makefntext[1]{%
    \parindent 1em%
    \noindent
    {\hbox{{\normalfont\@thefnmark.~}}}#1}


\input{cc.sty}
